
### CODE FOR META-ANALYSIS

##Set working drive
setwd("/Users/")

##Load Packages
library("metafor")

##Load data
df <- read.csv("database_MetaAnalysis.csv", header=TRUE)

##SELECT ONLY PAPERS THAT REPORT ABUNDANCE DATA
df$time.since.intro.regression<-as.character(df$time.since.intro.regression)
dd <- df[which(df$time.since.intro.regression=="Y"),]

##PREPARE DATA FOR ANALYSIS
df1 <- escalc(measure = "SMD", m1i=invaded.mean, sd1i=invaded.sd, n1i=invaded.N, m2i=uninvaded.mean, sd2i=uninvaded.sd, n2i=uninvaded.N, vtype="UB", data=dd)

#SELECT ONLY PAPERS THAT HAVE BOTH EXOTIC AND NATIVE RESPONSE ANIMALS
df1$meta.analysis<-as.character(df1$meta.analysis)
df2 <- df1[which(df1$meta.analysis=="Y"),]
df2$meta.analysis<-as.factor(df2$meta.analysis)
df1$meta.analysis<-as.factor(df1$meta.analysis)

#REMOVE OBSERVATIONS WHERE NATIVITY IS UNKNOWN
df2$response.nativity<-as.character(df2$response.nativity)
df3 <- df2[which(df2$response.nativity=="exotic" | df2$response.nativity=="native"),]
df3$response.nativity<-as.factor(df3$response.nativity)

#########

#### INITIAL ANALYSIS - OVERALL MODEL ####
res <- rma.mv(yi, vi, random = ~ 1 | study.group/effect.id, data=df3)

## EXTRACT HETEROGENEITY STATISTICS
W <- diag(1/df3$vi)
X <- model.matrix(res)
P <- W - W %*% X %*% solve(t(X) %*% W %*% X) %*% t(X) %*% W
100 * sum(res$sigma2) / (sum(res$sigma2) + (res$k-res$p)/sum(diag(P)))

# EXTRACT I-SQUARED SPLIT INTO AMONG STUDIES AND WITHIN STUDIES
100 * res$sigma2 / (sum(res$sigma2) + (res$k-res$p)/sum(diag(P)))

#########

## ANALYSIS OF PHYLUM x NATIVITY
# subset for phyla: "Arthropoda", "Annelida", "Mollusca", & "Chordata"
df3$response.phy<-as.character(df3$response.phy)
df.phy <- df3[which(df3$response.phy=="Arthropoda" | df3$response.phy=="Annelida" | df3$response.phy=="Mollusca" | df3$response.phy=="Chordata"),]
df.phy$response.phy<-as.factor(df.phy$response.phy)

# mixed effects model
res.phy <- rma.mv(yi, vi, mods = ~ response.phy*response.nativity, random = ~ 1 | study.group/effect.id, data=df.phy)

#########

## ANALYSIS OF ECOSYSTEM TYPE x NATIVITY
# subset for "wet" & "dry" ecosystems
df3$wet.dry<-as.character(df3$wet.dry)
df3 <- df3[which(df3$wet.dry=="wet" | df3$wet.dry=="dry"),]
df3$wet.dry<-as.factor(df3$wet.dry)

# mixed effects model
res.wet.dry <- rma.mv(yi, vi, mods = ~ response.nativity*wet.dry, random = ~ 1 | study.group/effect.id, data=df3)

#########

## ANALYSIS OF ECOSYSTEM TYPE - USING ALL STUDIES THAT RECORDED ABUNDANCE
# subset all abundance data for "wet" & "dry" ecosystems
df1$wet.dry<-as.character(df1$wet.dry)
df1.eco.type <- df1[which(df1$wet.dry=="wet" | df1$wet.dry=="dry"),]
df1$wet.dry<-as.factor(df1$wet.dry)
df1.eco.type$wet.dry<-as.factor(df1.eco.type$wet.dry)

# mixed effects model
res.wet.dry.all.abundance <- rma.mv(yi, vi, mods = ~ wet.dry, random = ~ 1 | study.group/effect.id, data=df1.eco.type)

#########

## ANALYSIS OF TROPHIC GROUP x NATIVITY
# subset for "detritivore", "herbivore", "omnivore" & "predator" ecosystems
df3$response.troph <-as.character(df3$response.troph)
df.tg <- df3[which(df3$response.troph =="detritivore" |df3$response.troph =="herbivore"| df3$response.troph =="omnivore"|df3$response.troph =="predator"),]
df3$response.troph <-as.factor(df3$response.troph)
df.tg$response.troph <-as.factor(df.tg$response.troph)

# mixed effects model
res.tg <- rma.mv(yi, vi, mods = ~ response.nativity* response.troph, random = ~ 1 | study.group/effect.id, data=df.tg)

#########

## INVADER GROWTH HABIT x NATIVITY
# subset for "tree", "forb", & "graminoid" ecosystems
df3$invader.growth.habit<-as.character(df3$invader.growth.habit)
df.gh <- df3[which(df3$invader.growth.habit=="tree" | df3$invader.growth.habit=="forb" | df3$invader.growth.habit=="graminoid"),]
df3$invader.growth.habit<-as.factor(df3$invader.growth.habit)
df.gh$invader.growth.habit<-as.factor(df.gh$invader.growth.habit)

# mixed effects model
res.gh <- rma.mv(yi, vi, mods = ~ response.nativity*invader.growth.habit, random = ~ 1 | study.group/effect.id, data=df.gh)

#########

## TIME SINCE INTRODUCTION x NATIVITY 
# mixed effects model
res.time <- rma.mv(yi, vi, mods = ~ response.nativity*time.since.invader.intro, random = ~ 1 | study.group/effect.id, data=df3)

#########

## TIME SINCE INTRODUCTION - USING ALL STUDIES THAT RECORDED ABUNDANCE 
# remove rows where time since introduction was unknown
df1a<-subset(df1,(!is.na(df1$time.since.invader.intro)))

# mixed effects model
res.time.all.abundance <- rma.mv(yi, vi, mods = ~ time.since.invader.intro, random = ~ 1 | study.group/effect.id, data=df1a)


#########


### ASSESS POSSIBLE PUBLICATION BIAS ###

## OVERALL MODE 
# using a modified Egger's Regression following the method proposed by Nakagawa & Santos 2012:
prediction.res <- predict(res)
precision.res <- sqrt(1/df3$vi)
MR.res <- df3$yi - prediction.res$pred
zMR.res <- MR.res*precision.res
egger.res <- lm(zMR.res ~ precision.res)
summary(egger.res)


## MODEL OF PHYLUM x NATIVITY
# using a modified Egger's Regression following the method proposed by Nakagawa & Santos 2012:
prediction.res.phy <- predict(res.phy)
precision.res.phy <- sqrt(1/df.phy$vi)
MR.res.phy <- df.phy$yi - prediction.res.phy$pred
zMR.res.phy <- MR.res.phy*precision.res.phy 
egger.res.phy <- lm(zMR.res.phy ~ precision.res.phy)
summary(egger.res.phy)


### ASSESS TIME-LAG BIAS ###
res.year <- rma.mv(yi, vi, mods = ~ publication.year, random = ~ 1 | study.group/effect.id,  data=df3)
summary(res.year)


### CITATION:
# Nakagawa S & Santos E (2012) Methodological issues and advances in biological meta-analysis. Evolutionary Ecology 26:1253-1274

